/*version 0.2
by Erdener Gonenc
pixelenvision.com
*/

macroScript VRCMU
    category:             "Pixel Envision"
    buttonText:          "Cubemap Generator"
    tooltip:             "Vray Cubemap Generator for Unity v0.2"
    icon:                 #("Systems",2)

(

local cubemapgen 

rollout cubemapgen "Vray Cubemap Generator for Unity v0.2" width:280 height:180
(
	
	
	global origtype = GetRenderType()
	global origheight = renderHeight
	global origwidth = renderWidth
	global psize = 128
	global bsize = 0

	radioButtons map_size "Cubemap Map Segment Size" pos:[20,10] width:150 height:90 labels:#("16x16", "32x32", "64x64", "128x128", "256x256", "512x512", "1024x1024", "2048x2048") default:5 columns:2
	radioButtons blur_size "Blur (Experimental)" pos:[180,10] width:50 height:90 labels:#("None", "Low", "Medium", "High") default:1 columns:1
	radioButtons map_type "Map Type" pos:[20,90] width:150 height:20 labels:#("Skybox", "Reflection") default:1 columns:2
	checkbutton sky_set "Make bottom piece 1/4 scale" pos:[20,125] width:160 height:20
	checkbutton rotate_set "Rotate back piece 180 degrees" pos:[20,145] width:160 height:20

	button b_render " Render!" pos:[190,100] width:80 height:60
	
	label lbl1 "Copyright 2012, Erdener Gonenc - PixelEnvision.com" pos:[15,165] width:265 height:15


fn CheckVrayRenderer rend =
(
	if (matchpattern (renderers.current as string) pattern:"*V_Ray*") then
	(
		return true
	)
	else	
	(	
		if (querybox "Vray isn't current Renderer, If you'd like Vray set as renderer click YES\n or click NO to exit" beep:false) then
		(
			rc = rendererClass.classes
			local vrClass
			for i = 1 to rc.count where (findstring (rc[ i ] as string) "V_Ray") != undefined do vrClass = i
			if (renderSceneDialog.isOpen()) then 
			(
				renderSceneDialog.close()
				execute ("renderers.current = " + rc[ vrClass ] as string + "()")
				renderSceneDialog.open()
			)
			return true
		)
		else destroydialog cubemapgen 
	)
)

on cubemapgen open do
(
	renderpresets.save 0 (GetDir #renderPresets + "\\vsai.tmp.rps") #{32}
	CheckVrayRenderer renderers.current	
)

on cubemapgen close do
(
	renderpresets.load 0 (GetDir #renderPresets + "\\vsai.tmp.rps") #{32}
)

on map_type changed state do
(
if state == 1 then 
(
sky_set.enabled = on
) else (
sky_set.state = off
sky_set.enabled = off
)
)
	
	fn SetpSize x =
	(
		CheckVrayRenderer renderers.current

		case map_size.state of
		(

			1: psize = 16

			2: psize = 32

			3: psize = 64

			4: psize = 128

			5: psize = 256

			6: psize = 512
			
			7: psize = 1024
			
			8: psize = 2048

		)
	

	)
	fn SetBlur x =
	(
		CheckVrayRenderer renderers.current

		case blur_size.state of
		(

			1: bsize = 0

			2: bsize = 5

			3: bsize = 10

			4: bsize = 15

		)
	

	)
	
	on b_render pressed do 
	(
		
		bmp = bitmaptexture()
		
		fname = selectSaveBitmap()
		if fname != undefined do bmp.filename = fname

		if (fname != undefined ) then (
		loc = findString bmp.filename "."
		
		SetpSize 0
		SetBlur 0
		
		if (bsize > 0) then (
		blurFilter = blur()
		blurFilter.name = "myBlur"
		blurFilter.blur_type = 0
		blurFilter.bUnifPixRad = bsize
		addEffect blurFilter
		)
		
		if (map_type.state == 1) then (
		cubecam = Freecamera fov:45 targetDistance:160 nearclip:1 farclip:1000 nearrange:0 farrange:1000 mpassEnabled:off mpassRenderPerPass:off transform:(matrix3 [1,0,0] [0,0,1] [0,-1,0] [0,0,0]) isSelected:on name:"cubecam"
		) else (
		cubecam = Freecamera fov:45 targetDistance:160 nearclip:1 farclip:1000 nearrange:0 farrange:1000 mpassEnabled:off mpassRenderPerPass:off transform:(matrix3 [1,0,0] [0,0,1] [0,-1,0] [0,0,0]) isSelected:on name:"cubecam"
		)
		viewport.setCamera cubecam
		
		execute "renderers.current.camera_type = 4"
		execute "renderers.current.output_on = false"
		execute ("renderers.current.colorMapping_gamma = " + fileOutGamma as string)

		oldState = renderSceneDialog.isOpen()
		if oldState do renderSceneDialog.Close()
		RenderWidth=psize*3
		RenderHeight=psize*4
		if oldState do renderSceneDialog.Open()
		
		setrendertype #crop
		rendSaveFile = true

		--top
		EditRenderRegion.EditRegion()
		viewport.setRegionRect viewport.activeViewport (Box2 psize 0 psize psize)
		EditRenderRegion.UpdateRegion() 
		if (map_type.state == 1) then (
		rendOutputFilename = replace bmp.filename loc 1 "_up."
		) else (
		rendOutputFilename = replace bmp.filename loc 1 "_top."
		)
		max quick render
		--top
		
		--front
		viewport.setRegionRect viewport.activeViewport (Box2 psize psize psize psize)
		EditRenderRegion.UpdateRegion()
		rendOutputFilename = replace bmp.filename loc 1 "_front."
		max quick render	
		--front
		
		--left
		viewport.setRegionRect viewport.activeViewport (Box2 (psize*2) psize psize psize)
		EditRenderRegion.UpdateRegion() 
		rendOutputFilename = replace bmp.filename loc 1 "_left."
		max quick render	
		--left
		
		--right
		viewport.setRegionRect viewport.activeViewport (Box2 0 psize psize psize)
		EditRenderRegion.UpdateRegion() 
		rendOutputFilename = replace bmp.filename loc 1 "_right."
		max quick render	
		--right
		
		--bottom
		
		viewport.setRegionRect viewport.activeViewport (Box2 psize (psize*2) psize psize)
		EditRenderRegion.UpdateRegion() 
		if (map_type.state == 1) then (
		rendOutputFilename = replace bmp.filename loc 1 "_down."
		) else (
		rendOutputFilename = replace bmp.filename loc 1 "_bottom."
		)
		if (sky_set.checked) then (
		RenderWidth=psize*3/4
		RenderHeight=psize*4/4
		)
		max quick render	
		--bottom

		if (sky_set.checked) then (
		RenderWidth=psize*3
		RenderHeight=psize*4
		)
		
		if (rotate_set.checked) then (
		cubecam.rotation.y_rotation = 180
		)
		
		--back
		viewport.setRegionRect viewport.activeViewport (Box2 psize (psize*3) psize psize)
		EditRenderRegion.UpdateRegion() 
		EditRenderRegion.EditRegion()
		rendOutputFilename = replace bmp.filename loc 1 "_back."
		max quick render
		--back
		
		delete cubecam
		if (bsize > 0) then (deleteEffect numEffects)
		setrendertype #view
		)
		renderpresets.load 0 (GetDir #renderPresets + "\\vsai.tmp.rps") #{32}
	)
	
	
)


fn GenerateDialog =
( 
	createdialog cubemapgen style:#(#style_border, #style_toolwindow, #style_sysmenu)						
)

fn DialogBGone =
(
	destroydialog cubemapgen 
)

if cubemapgen.indialog == true then DialogBGone() else GenerateDialog()

)